type ReportingFunc = (repo: ReportInfo[]) => void;
type GclResult = {
    filepath: string;
    position: string;
};
type UsageType = 'Unkown' | 'Get' | 'Modify' | 'Has' | 'Delete' | 'Method Call' | 'Function Call';
interface ReportInfo {
    newValue: any;
    oldValue: any;
    source: any;
    info: string;
    position: string;
    filepath?: string;
    usageTime: string;
    whenToAdd?: string;
    lastModify?: string;
    usageCount: number;
    isNewlyAdded: boolean;
    status: 'OK' | 'Fail';
    usageType: UsageType;
    dailyUsageRate: string;
    useageName: string | symbol;
}
interface MonitorUsageOptions {
    /**如果没有设置key，调用export方法导出的报告文件不会包含当前记录 */
    key?: string;
    /**当捕获错误时，页面是否展示错误提示框 */
    showErrorView?: boolean;
    /**是否可以修改属性值 */
    isModifyValue: boolean;
    /**是否允许添加属性 */
    allowAdditionalProps: boolean;
}
export default class MonitorUsageClass {
    static proxyMemo: WeakMap<WeakKey, any>;
    /**
     * 存储需要导出的报告信息
     */
    static recordsToExport: Record<string, ReportInfo[]>;
    /**
     * 存储监控对象的key调用次数
     */
    static keyUsesMap: Record<string | symbol, number>;
    /**
     * 临时存储报告记录
     */
    static tempRecords: WeakMap<object, ReportInfo[]>;
    /**
     * 当外部调用create方法时，创建的监控对象会和它的报告回调，弱存储在一起
     */
    static saveTraps: WeakMap<object, ReportingFunc>;
    /**
     * 监控对象为匿名函数时，因为没有函数名所有用id表示
     */
    static anonymousFid: number;
    private getReportObj;
    /**
     * 获取被监控代码所在的行和列数
     * @returns {GclResult}
     */
    static gcl(err: Error): GclResult;
    /**
     * 触发监视回调执行以及存储报告信息
     */
    static trap(data: {
        target: object;
        repo: ReportInfo;
        err: Error;
        recordKey?: string;
        callback?: ReportingFunc;
    }): void;
    private createStares;
    /**
     * 创建监控对象
     * @param {object} source 目标对象，非基本数据类型
     * @param {ReportingFunc} callback 监控的回调事件
     * @param {MonitorUsageOptions} options 配置选项
     * @returns
     */
    stares<T extends object>(source: T, callback: ReportingFunc, options?: MonitorUsageOptions): T;
    /**
     * 导出JSON格式的日志文件
     * @param useageName 文件名
     * @param _path 存放路径
     */
    export(useageName?: string, _path?: string): Promise<string>;
}
export {};
